@@ -7,4 +7,4 @@
 from . import cli
 
 if __name__ == '__main__':
-    cli.
+    cli.main()
